@@ -138,13 +138,14 @@ setMethod("getMetadataValue", "EnsDb", function(x, name){
 ############################################################
 ## seqinfo
 setMethod("seqinfo", "EnsDb", function(x){
-    Chrs <- dbGetQuery(dbconn(x), "select * from chromosome")
+    Chrs <- .fix_is_circular(dbGetQuery(dbconn(x), "select * from chromosome"))
     Chr.build <- .getMetaDataValue(dbconn(x), "genome_build")
     Chrs$seq_name <- formatSeqnamesFromQuery(x, Chrs$seq_name)
-    SI <- Seqinfo(seqnames=Chrs$seq_name,
-                  seqlengths=Chrs$seq_length,
-                  isCircular=Chrs$is_circular==1, genome=Chr.build)
-    return(SI)
+    SI <- Seqinfo(seqnames = Chrs$seq_name,
+                  seqlengths = Chrs$seq_length,
+                  isCircular = Chrs$is_circular == 1,
+                  genome = Chr.build)
+    SI
 })
 
 ############################################################
@@ -313,15 +314,15 @@ setMethod("listColumns", "EnsDb", function(x,
                                            table,
                                            skip.keys = TRUE,
                                            metadata = FALSE, ...){
-    if(length(x@tables)==0){
+    if (length(x@tables) == 0) {
         tables <- dbListTables(dbconn(x))
         ## read the columns for these tables.
-        Tables <- vector(length=length(tables), "list")
-        for(i in 1:length(Tables)){
-            Tables[[ i ]] <- colnames(dbGetQuery(dbconn(x),
-                                                 paste0("select * from ",
-                                                        tables[ i ],
-                                                        " limit 1")))
+        Tables <- vector(length = length(tables), "list")
+        for (i in 1:length(Tables)){
+            Tables[[i]] <- colnames(dbGetQuery(dbconn(x),
+                                               paste0("select * from ",
+                                                      tables[i],
+                                                      " limit 1")))
         }
         names(Tables) <- tables
         x@tables <- Tables
@@ -334,21 +335,20 @@ setMethod("listColumns", "EnsDb", function(x,
     Tab$tx <- unique(c(Tab$tx, "tx_name"))
     ## Manually add the symbol as a "virtual" column.
     Tab$gene <- unique(c(Tab$gene, "symbol"))
-    if(!missing(table)){
+    if (!missing(table))
         columns <- unlist(Tab[names(Tab) %in% table], use.names = FALSE)
-    }else{
+    else
         columns <- unlist(Tab, use.names=FALSE)
-    }
-    if(skip.keys){
+    if (skip.keys) {
         ## remove everything that has a _pk or _fk...
-        idx <- grep(columns, pattern="_fk$")
+        idx <- grep(columns, pattern = "_fk$")
         if(length(idx) > 0)
             columns <- columns[ -idx ]
         idx <- grep(columns, pattern="_pk$")
         if(length(idx) > 0)
             columns <- columns[ -idx ]
     }
-    return(unique(columns))
+    unique(columns)
 })
 
 ############################################################
@@ -1444,12 +1444,14 @@ setMethod(
             if(all(c(!is.null(chromosome), !is.null(start), !is.null(end)))){
                 ## Fix eventually provided UCSC chromosome names:
                 chromosome <- ucscToEns(chromosome)
-                ## Define a GRangesFilter to include all features that overlap
-                ## that region.
-                grg <- GRangesFilter(GRanges(seqnames = chromosome,
-                                             ranges = IRanges(start, end)),
-                                     feature = "tx", type = "any")
-                tids <- transcripts(x, filter = grg, columns = "tx_id")$tx_id
+                grg <- GRanges(seqnames = chromosome,
+                               ranges = IRanges(start, end))
+                tids <- transcripts(
+                    x, filter = GRangesFilter(grg, feature = "tx",
+                                              type = "any"),
+                    columns = "tx_id", return.type = "data.frame")$tx_id
+                if (!length(tids))
+                    return(GRanges())
                 filter <- AnnotationFilterList(filter, TxIdFilter(tids))
             }else{
                 stop("Either all or none of arguments 'chromosome', 'start' and",
