@@ -139,7 +139,8 @@ makeEnsemblSQLiteFromTables <- function(path=".", dbname){
     message("Processing 'trancript' table ... ", appendLF = FALSE)
     ## process transcripts:
     tmp <- read.table(paste0(path, .Platform$file.sep, "ens_tx.txt"),
-                      sep="\t", as.is=TRUE, header=TRUE)
+                      sep="\t", as.is=TRUE, header=TRUE, quote = "",
+                      comment.char = "")
     ## Check that we have the expected number of rows:
     if (haveCounts)
         if (nrow(tmp) != counts[1, "tx"])
@@ -242,6 +243,7 @@ makeEnsemblSQLiteFromTables <- function(path=".", dbname){
                                              "exon_idx", "tx_cds_seq_start",
                                              "tx_cds_seq_end", "prot_dom_start",
                                              "prot_dom_end")) {
+    if (!nrow(x)) return(TRUE)
     cols <- columns[columns %in% colnames(x)]
     if(length(cols) > 0) {
         sapply(cols, function(z) {
@@ -249,7 +251,7 @@ makeEnsemblSQLiteFromTables <- function(path=".", dbname){
                 stop("Column '", z,"' is not of type integer!")
         })
     }
-    return(TRUE)
+    TRUE
 }
 
 ####
